@@ -2,7 +2,7 @@ from .generic_diff_reporter import GenericDiffReporter, create_config
 
 
 class ReportWithVSCodeMacOS(GenericDiffReporter):
-    def __init__(self):
+    def __init__(self) -> None:
         super().__init__(
             config=create_config(
                 [
@@ -15,5 +15,5 @@ class ReportWithVSCodeMacOS(GenericDiffReporter):
 
 
 class ReportWithVSCode(GenericDiffReporter):
-    def __init__(self):
+    def __init__(self) -> None:
         super().__init__(config=create_config(["ReportWithVSCode", "code", ["-d"]]))
